pub struct PreparedInput { /* private fields */ }Implementations
Sourceimpl PreparedInput
impl PreparedInput
Sourcepub fn kind(&self) -> PreparedInputKind
pub fn kind(&self) -> PreparedInputKind
The operation semantic used to validate its readiness permit.
Sourcepub fn writes(&self) -> &[PreparedWrite]
pub fn writes(&self) -> &[PreparedWrite]
Inspect the bounded write sequence without making it mutable or forgeable.
pub fn into_writes(self) -> Vec<PreparedWrite>